From 8d1903ebca853bb74e524bd4bf01ec678481e50e Mon Sep 17 00:00:00 2001
From: Hayato Kuroda <kuroda.hayato@fujitsu.com>
Date: Mon, 6 Jan 2025 13:08:04 +0000
Subject: [PATCH] Avoid activating commit_ts while bootstrap

---
 src/backend/access/transam/commit_ts.c | 7 +++++++
 1 file changed, 7 insertions(+)

diff --git a/src/backend/access/transam/commit_ts.c b/src/backend/access/transam/commit_ts.c
index 95049acd0b..ea42d3a95e 100644
--- a/src/backend/access/transam/commit_ts.c
+++ b/src/backend/access/transam/commit_ts.c
@@ -707,6 +707,13 @@ ActivateCommitTs(void)
 	TransactionId xid;
 	int64		pageno;
 
+	/*
+	 * commit_ts assumes that we are not in the bootstrap mode: skip the
+	 * activation.
+	 */
+	if (IsBootstrapProcessingMode())
+		return;
+
 	/* If we've done this already, there's nothing to do */
 	LWLockAcquire(CommitTsLock, LW_EXCLUSIVE);
 	if (commitTsShared->commitTsActive)
-- 
2.43.0

